# Metacity

[![Build Status](https://github.com/MetacitySuite/Metacity/workflows/pytesting/badge.svg)](https://github.com/MetacitySuite/Metacity/actions?query=workflow%3Apytesting)
[![Coverage Status](https://coveralls.io/repos/github/MetacitySuite/Metacity/badge.svg?branch=main)](https://coveralls.io/github/MetacitySuite/Metacity?branch=main)

Toolkit for Urban Data processing

https://pypi.org/project/metacity/

